---
title: DH5.
---

This page contains all DH5 class methods. If you wonder how to start with `dh5` library, please refer to the [First Steps guide](../starting_guide/first_steps.md).

<!-- prettier-ignore -->
::: dh5.DH5
    options:
      show_bases: false
      show_root_heading: false
      summary: false
